<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="sv">
<context>
    <name>AmmoSchemeModel</name>
    <message>
        <source>new</source>
        <translation>ny</translation>
    </message>
    <message>
        <source>copy of</source>
        <translation>kopia av</translation>
    </message>
</context>
<context>
    <name>DrawMapWidget</name>
    <message>
        <source>File error</source>
        <translation>Fel på fil</translation>
    </message>
    <message>
        <source>Cannot open file &apos;%1&apos; for writing</source>
        <translation>Kan inte skriva till &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Cannot read file &apos;%1&apos;</source>
        <translation>Kan inte läsa &apos;%1&apos;</translation>
    </message>
</context>
<context>
    <name>FreqSpinBox</name>
    <message>
        <source>Never</source>
        <translation>Aldrig</translation>
    </message>
    <message numerus="yes">
        <source>Every %1 turn</source>
        <translation>
            <numerusform>Var %1 tur</numerusform>
            <numerusform>Var %1 tur</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>GameCFGWidget</name>
    <message>
        <source>Edit weapons</source>
        <translation>Redigera vapenset</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fel</translation>
    </message>
    <message>
        <source>Illegal ammo scheme</source>
        <translation>Ogiltigt vapenschema</translation>
    </message>
    <message>
        <source>Edit schemes</source>
        <translation>Redigera spelscheman</translation>
    </message>
    <message>
        <source>When this option is enabled selecting a game scheme will auto-select a weapon</source>
        <translation>När det här valet är aktivt kommer vapnen att ändras när du ändrar spelschema</translation>
    </message>
</context>
<context>
    <name>HWChatWidget</name>
    <message>
        <source>%1 *** %2 has been removed from your ignore list</source>
        <translation>%1 *** %2 har tagits bort från din ignoreringslista</translation>
    </message>
    <message>
        <source>%1 *** %2 has been added to your ignore list</source>
        <translation>%1 *** %2 har lagts till i din ignoreringslista</translation>
    </message>
    <message>
        <source>%1 *** %2 has been removed from your friends list</source>
        <translation>%1 *** %2 har tagits bort från din kompislista</translation>
    </message>
    <message>
        <source>%1 *** %2 has been added to your friends list</source>
        <translation>%1 *** %2 har lagts till i din kompislista</translation>
    </message>
</context>
<context>
    <name>HWForm</name>
    <message>
        <source>Error</source>
        <translation>Fel</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Unable to start the server</source>
        <translation>Kunde inte starta servern</translation>
    </message>
    <message>
        <source>Cannot save record to file %1</source>
        <translation>Kan inte spara inspelning till fil %1</translation>
    </message>
    <message>
        <source>new</source>
        <translation type="obsolete">ny</translation>
    </message>
    <message>
        <source>Please select record from the list above</source>
        <translation>Var god välj inspelning från listan ovanför</translation>
    </message>
    <message>
        <source>DefaultTeam</source>
        <translation>Standardlag</translation>
    </message>
    <message>
        <source>Hedgewars Demo File</source>
        <comment>File Types</comment>
        <translation>Demo-fil för Hedgewars</translation>
    </message>
    <message>
        <source>Hedgewars Save File</source>
        <comment>File Types</comment>
        <translation>Sparfil för Hedgewars</translation>
    </message>
    <message>
        <source>Demo name</source>
        <translation>Demonamn</translation>
    </message>
    <message>
        <source>Demo name:</source>
        <translation>Demonamn:</translation>
    </message>
</context>
<context>
    <name>HWGame</name>
    <message>
        <source>en.txt</source>
        <translation>sv.txt</translation>
    </message>
    <message>
        <source>Cannot open demofile %1</source>
        <translation>Kan inte öppna demofil %1</translation>
    </message>
</context>
<context>
    <name>HWMapContainer</name>
    <message>
        <source>Map</source>
        <translation>Karta</translation>
    </message>
    <message>
        <source>Themes</source>
        <translation>Teman</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filter</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Alla</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Liten</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Medel</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Stor</translation>
    </message>
    <message>
        <source>Cavern</source>
        <translation>Grotta</translation>
    </message>
    <message>
        <source>Wacky</source>
        <translation>Galen</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <source>Small tunnels</source>
        <translation>Små tunnlar</translation>
    </message>
    <message>
        <source>Medium tunnels</source>
        <translation>Medelstora tunnlar</translation>
    </message>
    <message>
        <source>Large tunnels</source>
        <translation>Stora tunnlar</translation>
    </message>
    <message>
        <source>Small floating islands</source>
        <translation>Små flytande öar</translation>
    </message>
    <message>
        <source>Medium floating islands</source>
        <translation>Medelstora flytande öar</translation>
    </message>
    <message>
        <source>Large floating islands</source>
        <translation>Stora flytande öar</translation>
    </message>
    <message>
        <source>Seed</source>
        <translation>Frö</translation>
    </message>
    <message>
        <source>Set</source>
        <translation>Ange</translation>
    </message>
</context>
<context>
    <name>HWNetServersModel</name>
    <message>
        <source>Title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
</context>
<context>
    <name>HWNewNet</name>
    <message>
        <source>The host was not found. Please check the host name and port settings.</source>
        <translation>Värden hittades inte. Var god kontrollera värdnamnet och portinställningarna.</translation>
    </message>
    <message>
        <source>Connection refused</source>
        <translation>Annslutning nekad</translation>
    </message>
    <message>
        <source>Quit reason: </source>
        <translation>Anledning: </translation>
    </message>
    <message>
        <source>Room destroyed</source>
        <translation>Rum tillintetgjort</translation>
    </message>
    <message>
        <source>You got kicked</source>
        <translation>Du sparkades ut</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Lösenord</translation>
    </message>
    <message>
        <source>Your nickname %1 is
registered on Hedgewars.org
Please provide your password
or pick another nickname:</source>
        <translation type="obsolete">Ditt smeknamn (%1) är
registrerat på Hedgewars.org
Var god ange ditt lösenord
eller välj ett annat smeknamn:</translation>
    </message>
    <message>
        <source>%1 *** %2 has joined the room</source>
        <translation>%1 *** %2 har gått med i rummet</translation>
    </message>
    <message>
        <source>%1 *** %2 has joined</source>
        <translation>%1 *** %2 har gått med</translation>
    </message>
    <message>
        <source>%1 *** %2 has left (%3)</source>
        <translation>%1 *** %2 har lämnat (%3)</translation>
    </message>
    <message>
        <source>%1 *** %2 has left</source>
        <translation>%1 *** %2 har lämnat</translation>
    </message>
    <message>
        <source>Your nickname %1 is
registered on Hedgewars.org
Please provide your password below
or pick another nickname in game config:</source>
        <translation>Ditt smeknamn (%1) är
registrerat på Hedgewars.org
Var god ange ditt lösenord eller välj
ett annat smeknamn i spelinställningarna:</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Smeknamn</translation>
    </message>
    <message>
        <source>Some one already uses
 your nickname %1
on the server.
Please pick another nickname:</source>
        <translation>Någon använder redan
ditt smeknamn %1
på servern.
Välj ett annat smeknamn:</translation>
    </message>
</context>
<context>
    <name>KB</name>
    <message>
        <source>SDL_ttf returned error while rendering text, most propably it is related to the bug in freetype2. It&apos;s recommended to update your freetype lib.</source>
        <translation>Fel uppstod då SDL_ttf skulle rendera text. Det beror högst troligen på felet i freetype2. Du rekommenderas att uppdatera ditt freetype-bibliotek.</translation>
    </message>
</context>
<context>
    <name>PageAdmin</name>
    <message>
        <source>Server message:</source>
        <translation type="obsolete">Servermeddelande</translation>
    </message>
    <message>
        <source>Set message</source>
        <translation type="obsolete">Ställ in meddelande</translation>
    </message>
    <message>
        <source>Clear Accounts Cache</source>
        <translation>Töm användarcache</translation>
    </message>
    <message>
        <source>Fetch data</source>
        <translation>Hämta data</translation>
    </message>
    <message>
        <source>Server message for latest version:</source>
        <translation>Servermaddelande för senaste versionen:</translation>
    </message>
    <message>
        <source>Server message for previous versions:</source>
        <translation>Servermeddelande för tidigare versioner:</translation>
    </message>
    <message>
        <source>Latest version protocol number:</source>
        <translation>Senaste versionens protokollnummer:</translation>
    </message>
    <message>
        <source>MOTD preview:</source>
        <translation>MOTD-förhandsvisning:</translation>
    </message>
    <message>
        <source>Set data</source>
        <translation>Ange data</translation>
    </message>
</context>
<context>
    <name>PageConnecting</name>
    <message>
        <source>Connecting...</source>
        <translation>Ansluter...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
</context>
<context>
    <name>PageDrawMap</name>
    <message>
        <source>Undo</source>
        <translation>Ångra</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Rensa</translation>
    </message>
    <message>
        <source>Load</source>
        <translation>Läs in</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Spara</translation>
    </message>
    <message>
        <source>Load drawn map</source>
        <translation>Läs in ritad karta</translation>
    </message>
    <message>
        <source>Drawn Maps (*.hwmap);;All files (*.*)</source>
        <translation type="obsolete">Ritade kartor (*.hwmap);;Alla filer (*.*)</translation>
    </message>
    <message>
        <source>Save drawn map</source>
        <translation>Spara ritad karta</translation>
    </message>
    <message>
        <source>Drawn Maps</source>
        <translation>Ritade kartor</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Alla filer</translation>
    </message>
</context>
<context>
    <name>PageEditTeam</name>
    <message>
        <source>General</source>
        <translation>Allmänt</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Avancerat</translation>
    </message>
</context>
<context>
    <name>PageGameStats</name>
    <message>
        <source>&lt;p&gt;The best shot award was won by &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; pts.&lt;/p&gt;</source>
        <translation type="obsolete">&lt;p&gt;Priset för bästa skott går till &lt;b&gt;%1&lt;/b&gt; med &lt;b&gt;%2&lt;/b&gt; poäng.&lt;/p&gt;</translation>
    </message>
    <message numerus="yes">
        <source>&lt;p&gt;The best killer is &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; kills in a turn.&lt;/p&gt;</source>
        <translation type="obsolete">
            <numerusform>&lt;p&gt;Den bästa mördaren är &lt;b&gt;%1&lt;/b&gt; med &lt;b&gt;%2&lt;/b&gt; dödad på samma tur.&lt;/p&gt;</numerusform>
            <numerusform>&lt;p&gt;Den bästa mördaren är &lt;b&gt;%1&lt;/b&gt; med &lt;b&gt;%2&lt;/b&gt; dödade på samma tur.&lt;/p&gt;</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>&lt;p&gt;A total of &lt;b&gt;%1&lt;/b&gt; hedgehog(s) were killed during this round.&lt;/p&gt;</source>
        <translation type="obsolete">
            <numerusform>&lt;p&gt;Totalt &lt;b&gt;%1&lt;/b&gt; igelkott dödades denna omgång.&lt;/p&gt;</numerusform>
            <numerusform>&lt;p&gt;Totalt &lt;b&gt;%1&lt;/b&gt; igelkottar dödades denna omgång.&lt;/p&gt;</numerusform>
        </translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detaljer</translation>
    </message>
    <message>
        <source>Health graph</source>
        <translation>Livgraf</translation>
    </message>
    <message>
        <source>Ranking</source>
        <translation>Rankning</translation>
    </message>
    <message>
        <source>The best shot award was won by &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; pts.</source>
        <translation>Bästa skott-priset vanns av &lt;b&gt;%1&lt;/b&gt; med &lt;b&gt;%2&lt;/b&gt; poäng.</translation>
    </message>
    <message numerus="yes">
        <source>The best killer is &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; kills in a turn.</source>
        <translation>
            <numerusform>Bästa dödaren är &lt;b&gt;%1&lt;/b&gt; med &lt;b&gt;%2&lt;/b&gt; döda på en tur.</numerusform>
            <numerusform>Bästa dödaren är &lt;b&gt;%1&lt;/b&gt; med &lt;b&gt;%2&lt;/b&gt; döda på en tur.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>A total of &lt;b&gt;%1&lt;/b&gt; hedgehog(s) were killed during this round.</source>
        <translation>
            <numerusform>Totalt &lt;b&gt;%1&lt;/b&gt; igelkott(ar) dödades under den här omgången.</numerusform>
            <numerusform>Totalt &lt;b&gt;%1&lt;/b&gt; igelkott(ar) dödades under den här omgången.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>(%1 kill)</source>
        <translation>
            <numerusform>(%1 död)</numerusform>
            <numerusform>(%1 döda)</numerusform>
        </translation>
    </message>
    <message>
        <source>(%1 kills)</source>
        <translation type="obsolete">(%1 döda)</translation>
    </message>
    <message numerus="yes">
        <source>&lt;b&gt;%1&lt;/b&gt; thought it&apos;s good to shoot his own hedgehogs with &lt;b&gt;%2&lt;/b&gt; pts.</source>
        <translation>
            <numerusform>&lt;b&gt;%1&lt;/b&gt; tyckte att det var bra att sjuta sina egna igelkottar med &lt;b&gt;%2&lt;/b&gt; poäng.</numerusform>
            <numerusform>&lt;b&gt;%1&lt;/b&gt; tyckte att det var bra att sjuta sina egna igelkottar med &lt;b&gt;%2&lt;/b&gt; poäng.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>&lt;b&gt;%1&lt;/b&gt; killed &lt;b&gt;%2&lt;/b&gt; of his own hedgehogs.</source>
        <translation>
            <numerusform>&lt;b&gt;%1&lt;/b&gt; dödade &lt;b&gt;%2&lt;/b&gt; av sina egna igelkottar.</numerusform>
            <numerusform>&lt;b&gt;%1&lt;/b&gt; dödade &lt;b&gt;%2&lt;/b&gt; av sina egna igelkottar.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>&lt;b&gt;%1&lt;/b&gt; was scared and skipped turn &lt;b&gt;%2&lt;/b&gt; times.</source>
        <translation>
            <numerusform>&lt;b&gt;%1&lt;/b&gt; var rädd och hoppade över turer &lt;b&gt;%2&lt;/b&gt; gånger.</numerusform>
            <numerusform>&lt;b&gt;%1&lt;/b&gt; var rädd och hoppade över turer &lt;b&gt;%2&lt;/b&gt; gånger.</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>PageMain</name>
    <message>
        <source>Local Game (Play a game on a single computer)</source>
        <translation>Lokalt spel (Spela en omgång på en enskild dator)</translation>
    </message>
    <message>
        <source>Network Game (Play a game across a network)</source>
        <translation>Nätverkspel (Spela en omgång över ett nätverk)</translation>
    </message>
    <message>
        <source>Simply pick the same color as a friend to play together as a team. Each of you will still control his or her own hedgehogs but they&apos;ll win or lose together.</source>
        <comment>Tips</comment>
        <translation>Välj bara samma färg som en vän för att spela i som ett lag. Varje spelare kontrollerar fortfarande själva sina igelkottar men de vinner eller förlorar tillsammans.</translation>
    </message>
    <message>
        <source>Some weapons might do only low damage but they can be a lot more devastating in the right situation. Try to use the Desert Eagle to knock multiple hedgehogs into the water.</source>
        <comment>Tips</comment>
        <translation>Några vapen kanske bara gör liten skada men de kan vara mycket mer förödande i rätt situation. Försök att använda Desert Eagle för att putta ner flera igelkottar ner i vattnet.</translation>
    </message>
    <message>
        <source>If you&apos;re unsure what to do and don&apos;t want to waste ammo, skip one round. But don&apos;t let too much time pass as there will be Sudden Death!</source>
        <comment>Tips</comment>
        <translation>Om du inte är säker på vad du ska göra och inte vill slösa på ammunition, hoppa över en tur. Men låt inte för lång tid passera eftersom sudden death kommer!</translation>
    </message>
    <message>
        <source>Want to save ropse? Release the rope in mid air and then shoot again. As long as you don&apos;t touch the ground you&apos;ll reuse your rope without wasting ammo!</source>
        <comment>Tips</comment>
        <translation type="obsolete">Vill du spara rep? Släpp repet i luften och sedan sjut igen. Så länge du inte nuddar marken använder du samma rep utan att slösa på ammunition!</translation>
    </message>
    <message>
        <source>If you&apos;d like to keep others from using your preferred nickname on the official server, register an account at http://www.hedgewars.org/.</source>
        <comment>Tips</comment>
        <translation>Om du vill förhindra andra från att använda ditt favoritnamn på den officiella servern kan du registrera ett konto på http://www.hedgewars.org/.</translation>
    </message>
    <message>
        <source>You&apos;re bored of default gameplay? Try one of the missions - they&apos;ll offer different gameplay depending on the one you picked.</source>
        <comment>Tips</comment>
        <translation>Är du trött på att spela vanligt? Pröva ett av uppdragen - de erbjuder annorlunda spel beroende på vilken du väljer.</translation>
    </message>
    <message>
        <source>By default the game will always record the last game played as a demo. Select &apos;Local Game&apos; and pick the &apos;Demos&apos; button on the lower right corner to play or manage them.</source>
        <comment>Tips</comment>
        <translation>Som standard spelar spelet alltid in den senaste matchen som en demo. Välj &apos;Lokalt Spel&apos; och tryck på &apos;Demo&apos;-knappen nere till höger för att spela eller hantera dem.</translation>
    </message>
    <message>
        <source>Hedgewars is Open Source and Freeware we create in our spare time. If you&apos;ve got problems, ask on our forums but please don&apos;t expect 24/7 support!</source>
        <comment>Tips</comment>
        <translation>Hedgewars är ett öppet källkods- och gratisprogram som vi skapar på vår fritid. Om du har problem, fråga på vårat forum men snälla förvänta dig inte dygnet runt-support!</translation>
    </message>
    <message>
        <source>Hedgewars is Open Source and Freeware we create in our spare time. If you like it, help us with a small donation or contribute your own work!</source>
        <comment>Tips</comment>
        <translation>Hedgewars är ett öppet källkods- och gratisprogram som vi skapar på vår fritid. Om du gillar det, hjälp oss med en liten donation eller bidra med något eget!</translation>
    </message>
    <message>
        <source>Hedgewars is Open Source and Freeware we create in our spare time. Share it with your family and friends as you like!</source>
        <comment>Tips</comment>
        <translation>Hedgewars är ett öppet källkods- och gratisprogram som vi skapar på vår fritid. Dela med dig av det till familj och vänner som du vill!</translation>
    </message>
    <message>
        <source>From time to time there will be official tournaments. Upcoming events will be announced at http://www.hedgewars.org/ some days in advance.</source>
        <comment>Tips</comment>
        <translation>Då och då kommer det hållas officiella turneringer. Kommande händelser kommer att annonseras på http://www.hedgewars.org/ några dagar i förväg.</translation>
    </message>
    <message>
        <source>Hedgewars is available in many languages. If the translation in your language seems to be missing or outdated, feel free to contact us!</source>
        <comment>Tips</comment>
        <translation>Hedgewars finns på många språk. Om översättningen på ditt språk verkar saknas eller är gammal får du gärna kontakta oss!</translation>
    </message>
    <message>
        <source>Hedgewars can be run on lots of different operating systems including Microsoft Windows, Mac OS X and Linux.</source>
        <comment>Tips</comment>
        <translation>Hedgewars kan köras på många operativsystem som Microsoft Windows, Mac OS X och Linux.</translation>
    </message>
    <message>
        <source>Always remember you&apos;re able to set up your own games in local and network/online play. You&apos;re not restricted to the &apos;Simple Game&apos; option.</source>
        <comment>Tips</comment>
        <translation>Kom alltid ihåg att du kan starta en egen match i lokalt och netverk/online-spel. Du är inte begränsad till &apos;Enkelt spel&apos;-valet.</translation>
    </message>
    <message>
        <source>While playing you should give yourself a short break at least once an hour.</source>
        <comment>Tips</comment>
        <translation>När du spelar borde du ta en pause åt minståne en gång i timman.</translation>
    </message>
    <message>
        <source>If your graphics card isn&apos;t able to provide hardware accelerated OpenGL, try to enable the low quality mode to improve performance.</source>
        <comment>Tips</comment>
        <translation>Om ditt grafikkort inte klarar av att ge hårdvaruaccellererad OpenGL, pröva att sänka kvaliteten för att öka prestandan.</translation>
    </message>
    <message>
        <source>We&apos;re open to suggestions and constructive feedback. If you don&apos;t like something or got a great idea, let us know!</source>
        <comment>Tips</comment>
        <translation>Vi är öppna för förslag och konstruktiv kritik. Om du inte gillar något eller har en bra idé, hör av dig!</translation>
    </message>
    <message>
        <source>Especially while playing online be polite and always remember there might be some minors playing with or against you as well!</source>
        <comment>Tips</comment>
        <translation>Speciellt när du spelar över netet, var artig och kom alltid ihåg att det kan vara minderåriga som du spelar mot också!</translation>
    </message>
    <message>
        <source>Special game modes such as &apos;Vampirism&apos; or &apos;Karma&apos; allow you to develop completely new tactics. Try them in a custom game!</source>
        <comment>Tips</comment>
        <translation>Speciella spellägen som &apos;Vampyrism&apos; eller &apos;Karma&apos; låter dig utveckla helt nya taktiker. Pröva dem i ett eget spel!</translation>
    </message>
    <message>
        <source>The Windows version of Hedgewars supports Xfire. Make sure to add Hedgwars to its game list so your friends can see you playing.</source>
        <comment>Tips</comment>
        <translation type="obsolete">Windows-versionen av Hedgewars har stöd för Xfire. Se till att lägga till Hedgewars till spellistan så att dina vänner kan se dig spela.</translation>
    </message>
    <message>
        <source>You should never install Hedgewars on computers you don&apos;t own (school, university, work, etc.). Please ask the responsible person instead!</source>
        <comment>Tips</comment>
        <translation>Du ska aldrig installera Hedgewars på en dator som du inte äger (skola, universitet, arbete, etc.). Fråga den ansvarige personen istället!</translation>
    </message>
    <message>
        <source>Hedgewars can be perfect for short games during breaks. Just ensure you don&apos;t add too many hedgehogs or use an huge map. Reducing time and health might help as well.</source>
        <comment>Tips</comment>
        <translation>Hedgewars kan vara perfekt för korta matcher under raster. Se bara till att du inte lägger till för många igelkottar eller använder en stor bana. Att minska tiden och hälsa kan också hjälpa.</translation>
    </message>
    <message>
        <source>No hedgehogs were harmed in making this game.</source>
        <comment>Tips</comment>
        <translation>Inga igelkottar skadades under produktionen av spelet.</translation>
    </message>
    <message>
        <source>Hedgewars is Open Source and Freeware we create in our spare time. If someone sold you the game, you should try get a refund!</source>
        <comment>Tips</comment>
        <translation>Hedgewars är ett öppet källkods- och gratisprogram som vi skapar på vår fritid. Om någon sålde spelet till dig ska du försöka att få pengarna tillbaka!</translation>
    </message>
    <message>
        <source>Connect one or more gamepads before starting the game to be able to assign their controls to your teams.</source>
        <comment>Tips</comment>
        <translation>Koppla ihop en eller flera spelplattor innan du startar spelet för att kunna välja att kontrollera era lag med dem.</translation>
    </message>
    <message>
        <source>Create an account on %1 to keep others from using your most favourite nickname while playing on the official server.</source>
        <comment>Tips</comment>
        <translation>Skapa ett konto på %1 för att förhindra andra från att använda ditt favoritnamn när du spelar på den officiella servern.</translation>
    </message>
    <message>
        <source>If your graphics card isn&apos;t able to provide hardware accelerated OpenGL, try to update the associated drivers.</source>
        <comment>Tips</comment>
        <translation>Om ditt grafikkort inte klarar av att ge hårdvaruaccellererad OpenGL, pröva att uppdatera dina drivrutiner.</translation>
    </message>
    <message>
        <source>There are three different jumps available. Tap [high jump] twice to do a very high/backwards jump.</source>
        <comment>Tips</comment>
        <translation>Det finns tre olika hopp tillgängliga. Tryck på [högt hopp] två gånger för att göra ett ett högt bakåt-hopp.</translation>
    </message>
    <message>
        <source>Afraid of falling off a cliff? Hold down [precise] to turn [left] or [right] without actually moving.</source>
        <comment>Tips</comment>
        <translation>Är du rädd att falla ner för an kant? Håll ner [exakt] för att vrida [vänster] eller [höger] utan att egentligen röra dig.</translation>
    </message>
    <message>
        <source>Some weapons require special strategies or just lots of training, so don&apos;t give up on a particular tool if you miss an enemy once.</source>
        <comment>Tips</comment>
        <translation>Några vapen kräver speciella strategier eller bara mycket träning, så ge inte upp ett vapen bara för att du missade en fiende någon gång.</translation>
    </message>
    <message>
        <source>Most weapons won&apos;t work once they touch the water. The Homing Bee as well as the Cake are exceptions to this.</source>
        <comment>Tips</comment>
        <translation>De flesta vapen fungerar inte när de har rört vattenet. Målsökande bi och även Tårta är två undantag.</translation>
    </message>
    <message>
        <source>The Old Limbuger only causes a small explosion. However the wind affected smelly cloud can poison lots of hogs at once.</source>
        <comment>Tips</comment>
        <translation>Den gamla Limburgaren skapar bara en liten explosition. Men det vindpåverkade stinkmålnet kan förgifta många igelkottar samtidigt.</translation>
    </message>
    <message>
        <source>The Piano Strike is the most damaging air strike. You&apos;ll lose the hedgehog performing it, so there&apos;s a huge downside as well.</source>
        <comment>Tips</comment>
        <translation>Pianoanfall är det farligaste luftanfallet. Du blir av med en igelkott när du använder det, så det finns en stor nackdel också.</translation>
    </message>
    <message>
        <source>The Homing Bee can be tricky to use. It&apos;s turn radius depends on it&apos;s velocity, so try to not use full power.</source>
        <comment>Tips</comment>
        <translation type="obsolete">Målsökande biet kan vara svårt att använda. Biets sväng beror på hastigheten, så försök inte att använda full kraft.</translation>
    </message>
    <message>
        <source>Sticky Mines are a perfect tool to create small chain reactions knocking enemy hedgehogs into dire situations ... or water.</source>
        <comment>Tips</comment>
        <translation>Fästande minor är ett perfekt verktyg för att skapa små kedjereaktioner som slår ner fiender i farliga situationer ... eller vatten.</translation>
    </message>
    <message>
        <source>The Hammer is most effective when used on bridges or girders. Hit hogs will just break through the ground.</source>
        <comment>Tips</comment>
        <translation>Hammaren är mest effektiv när den används på broar eller balkar. När du slår till igelkottarna kommer de att falla nergenom hålet.</translation>
    </message>
    <message>
        <source>If you&apos;re stuck behind an enemy hedgehog, use the Hammer to free yourself without getting damaged by an explosion.</source>
        <comment>Tips</comment>
        <translation>Om du är fast bakom en fiende, använd hammaren för att göra dig fri utan att skadas av en explosition.</translation>
    </message>
    <message>
        <source>The Cake&apos;s maximum walking distance depends on the ground it has to pass. Use [attack] to detonate it early.</source>
        <comment>Tips</comment>
        <translation>Tårtans längsta gångsträcka beror på vägen den måste ta. Använd [attack] för att spränga den tidigt.</translation>
    </message>
    <message>
        <source>The Flame Thrower is a weapon but it can be used for tunnel digging as well.</source>
        <comment>Tips</comment>
        <translation>Eldkastaren är ett vapen, men den kan användas för att gräva tunnlar också.</translation>
    </message>
    <message>
        <source>Use the Incinerating Grenade to temporary keep hedgehogs from passing terrain such as tunnels or platforms.</source>
        <comment>Tips</comment>
        <translation type="obsolete">Använd Molotov för att tillfälligt förhindra igelkottar från att passera terräng såsom tunnlar och platformer.</translation>
    </message>
    <message>
        <source>Want to know who&apos;s behind the game? Click on the Hedgewars logo in the main menu to see the credits.</source>
        <comment>Tips</comment>
        <translation>Vill du veta vilka som ligger bakom spelet? Tryck på Hedgewars-loggan i huvudmenyn för att se medverkande.</translation>
    </message>
    <message>
        <source>Like Hedgewars? Become a fan on %1 or follow us on %2!</source>
        <comment>Tips</comment>
        <translation>Gillar du Hedgewars? Bli ett fan på %1 eller följ oss på %2!</translation>
    </message>
    <message>
        <source>Feel free to draw your own graves, hats, flags or even maps and themes! But note that you&apos;ll have to share them somewhere to use them online.</source>
        <comment>Tips</comment>
        <translation>Du är välkommen att rita dina egna gravar, hattar, flaggor eller till och med banor eller teman! Men notera att du måste lägga ut dem någonstans för att använda dem online.</translation>
    </message>
    <message>
        <source>Really want to wear a specific hat? Donate to us and receive an exclusive hat of your choice!</source>
        <comment>Tips</comment>
        <translation>Vill du verkligen ha en specifik hatt? Ge os en donation och få en exklusiv hatt som du väljer!</translation>
    </message>
    <message>
        <source>Keep your video card drivers up to date to avoid issues playing the game.</source>
        <comment>Tips</comment>
        <translation>Se till att hålla dina grafikdrivrutiner uppdaterade för att undvika problem när du spalar.</translation>
    </message>
    <message>
        <source>You can find your Hedgewars configuration files under &quot;My Documents\Hedgewars&quot;. Create backups or take the files with you, but don&apos;t edit them by hand.</source>
        <comment>Tips</comment>
        <translation>Du kan hitta dina konfigurationsfiler under &quot;Mina Dokument\Hedgewars&quot;. Gör en säkerhetskopia eller ta med dig filerna, men redigera dem inte för hand.</translation>
    </message>
    <message>
        <source>You can find your Hedgewars configuration files under &quot;Hedgewars&quot; in your home directory. Create backups or take the files with you, but don&apos;t edit them by hand.</source>
        <comment>Tips</comment>
        <translation type="obsolete">Du kan hitta dina konfigurationsfiler under &quot;Hedgewars&quot; i din hem-mapp. Gör en säkerhetskopia eller ta med dig filerna, men redigera dem inte för hand.</translation>
    </message>
    <message>
        <source>You&apos;re able to associate Hedgewars related files (savegames and demo recordings) with the game to launch them right from your favorite file or internet browser.</source>
        <comment>Tips</comment>
        <translation>Du kan associera Hedgewars-relaterade filer (sparfiler och demo-inspelningar) med spelet för att köra dem direkt från den filhanterare eller webbläsare du tycker bäst om.</translation>
    </message>
    <message>
        <source>Want to save ropes? Release the rope in mid air and then shoot again. As long as you don&apos;t touch the ground you&apos;ll reuse your rope without wasting ammo!</source>
        <comment>Tips</comment>
        <translation>Vill du spara rep? Släpp repet i luften och sedan sjut igen. Så länge du inte nuddar marken använder du samma rep utan att slösa på ammunition!</translation>
    </message>
    <message>
        <source>You can find your Hedgewars configuration files under &quot;Library/Application Support/Hedgewars&quot; in your home directory. Create backups or take the files with you, but don&apos;t edit them by hand.</source>
        <comment>Tips</comment>
        <translation>Du kan hitta dina konfigurationsfiler under &quot;Library/Application Support/Hedgewars&quot; i din hem-mapp. Gör en säkerhetskopia eller ta med dig filerna, men redigera dem inte för hand.</translation>
    </message>
    <message>
        <source>You can find your Hedgewars configuration files under &quot;.hedgewars&quot; in your home directory. Create backups or take the files with you, but don&apos;t edit them by hand.</source>
        <comment>Tips</comment>
        <translation>Du kan hitta dina konfigurationsfiler under &quot;.hedgewars&quot; i din hem-mapp. Gör en säkerhetskopia eller ta med dig filerna, men redigera dem inte för hand.</translation>
    </message>
    <message>
        <source>The Windows version of Hedgewars supports Xfire. Make sure to add Hedgewars to its game list so your friends can see you playing.</source>
        <comment>Tips</comment>
        <translation>Windows-versionen av Hedgewars har stöd för Xfire. Se till att lägga till Hedgewars till spellistan så att dina vänner kan se dig spela.</translation>
    </message>
    <message>
        <source>Use the Molotov or Flame Thrower to temporary keep hedgehogs from passing terrain such as tunnels or platforms.</source>
        <comment>Tips</comment>
        <translation>Använd molotov eller eldkastaren för att temporärt förhindra att igelkottar passerar terräng så som tunnlar eller platformar.</translation>
    </message>
    <message>
        <source>The Homing Bee can be tricky to use. Its turn radius depends on its velocity, so try to not use full power.</source>
        <comment>Tips</comment>
        <translation>Målsökande bin kan vara kluriga att använda. Svängradien beror på hastigheten, så försök att inte använda full kraft.</translation>
    </message>
    <message>
        <source>Downloadable Content</source>
        <translation>Nedladdningsbart innehåll</translation>
    </message>
</context>
<context>
    <name>PageMultiplayer</name>
    <message>
        <source>Start</source>
        <translation>Starta</translation>
    </message>
</context>
<context>
    <name>PageNet</name>
    <message>
        <source>Error</source>
        <translation>Fel</translation>
    </message>
    <message>
        <source>Please select server from the list above</source>
        <translation>Var god välj server från listan ovanför</translation>
    </message>
</context>
<context>
    <name>PageNetGame</name>
    <message>
        <source>Control</source>
        <translation>Kontroll</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fel</translation>
    </message>
    <message>
        <source>Please enter room name</source>
        <translation>Skriv in rummets namn</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>PageNetType</name>
    <message>
        <source>LAN game</source>
        <translation>LAN-spel</translation>
    </message>
    <message>
        <source>Official server</source>
        <translation>Officiell server</translation>
    </message>
</context>
<context>
    <name>PageOptions</name>
    <message>
        <source>New team</source>
        <translation>Nytt lag</translation>
    </message>
    <message>
        <source>Edit team</source>
        <translation>Redigera lag</translation>
    </message>
    <message>
        <source>Delete team</source>
        <translation>Ta bort lag</translation>
    </message>
    <message>
        <source>New weapon scheme</source>
        <translation type="obsolete">Nytt vapenschema</translation>
    </message>
    <message>
        <source>Edit weapon scheme</source>
        <translation type="obsolete">Redigera vapenschema</translation>
    </message>
    <message>
        <source>Delete weapon scheme</source>
        <translation type="obsolete">Ta bort vapenschema</translation>
    </message>
    <message>
        <source>You can&apos;t edit teams from team selection. Go back to main menu to add, edit or delete teams.</source>
        <translation>Du kan inte redigera lag från ett spel. Gå tillbaka till huvudmenyn för att lägga till, redigera eller ta bort lag.</translation>
    </message>
    <message>
        <source>New scheme</source>
        <translation>Nytt schema</translation>
    </message>
    <message>
        <source>Edit scheme</source>
        <translation>Redigera schema</translation>
    </message>
    <message>
        <source>Delete scheme</source>
        <translation>Ta bort schema</translation>
    </message>
    <message>
        <source>New weapon set</source>
        <translation>Nytt vapenset</translation>
    </message>
    <message>
        <source>Edit weapon set</source>
        <translation>Redigera vapenset</translation>
    </message>
    <message>
        <source>Delete weapon set</source>
        <translation>Ta bort vapenset</translation>
    </message>
</context>
<context>
    <name>PagePlayDemo</name>
    <message>
        <source>Error</source>
        <translation>Fel</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Rename dialog</source>
        <translation>Namnbytesdialig</translation>
    </message>
    <message>
        <source>Enter new file name:</source>
        <translation>Skriv in nytt filnamn:</translation>
    </message>
    <message>
        <source>Cannot rename to</source>
        <translation>Kan inte byta namn till</translation>
    </message>
    <message>
        <source>Cannot delete file</source>
        <translation>Kan inte ta bort fil</translation>
    </message>
    <message>
        <source>Please select record from the list</source>
        <translation>Välj inspelning från listan</translation>
    </message>
</context>
<context>
    <name>PageRoomsList</name>
    <message>
        <source>Create</source>
        <translation>Skapa</translation>
    </message>
    <message>
        <source>Join</source>
        <translation>Anslut</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Uppdatera</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fel</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Admin features</source>
        <translation>Adminfunktioner</translation>
    </message>
    <message>
        <source>Room Name:</source>
        <translation>Rumnamn:</translation>
    </message>
    <message>
        <source>This game is in lobby.
You may join and start playing once the game starts.</source>
        <translation>Detta spel är i lobby.
Du kan gå med och börja spela när spelet börjar.</translation>
    </message>
    <message>
        <source>This game is in progress.
You may join and spectate now but you&apos;ll have to wait for the game to end to start playing.</source>
        <translation>Detta spel pågår.
Du kan gå med och se på men du måste vänta tills spelet är slut för att kunna börja spela.</translation>
    </message>
    <message>
        <source>%1 is the host. He may adjust settings and start the game.</source>
        <translation>%1 är ägaren. Han kan ändra inställningar och starta spelet.</translation>
    </message>
    <message>
        <source>Random Map</source>
        <translation>Slumpad karta</translation>
    </message>
    <message>
        <source>Games may be played on precreated or randomized maps.</source>
        <translation>Spel kan spelas på färdiga eller slumpade kartor.</translation>
    </message>
    <message>
        <source>The Game Scheme defines general options and preferences like Round Time, Sudden Death or Vampirism.</source>
        <translation>Spelschemat anger allmäna inställningar som tid per person, Sudden Death eller Vampyrism.</translation>
    </message>
    <message>
        <source>The Weapon Scheme defines available weapons and their ammunition count.</source>
        <translation>Vapenschemat anger tillgängliga vapen och deras ammunitionsantal.</translation>
    </message>
    <message numerus="yes">
        <source>There are %1 clients connected to this room.</source>
        <translation>
            <numerusform>Det är %1 klient uppkopplad till detta rum.</numerusform>
            <numerusform>Det är %1 klienter uppkopplade till detta rum.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>There are %1 teams participating in this room.</source>
        <translation>
            <numerusform>Det är %1 deltagande lag i detta rum.</numerusform>
            <numerusform>Det är %1 deltagande lag i detta rum.</numerusform>
        </translation>
    </message>
    <message>
        <source>Please enter room name</source>
        <translation>Skriv in rummets namn</translation>
    </message>
    <message>
        <source>Please select room from the list</source>
        <translation>Välj ett rum från listan</translation>
    </message>
    <message>
        <source>Random Maze</source>
        <translation>Slumpad labyrint</translation>
    </message>
    <message>
        <source>State:</source>
        <translation>Status:</translation>
    </message>
    <message>
        <source>Rules:</source>
        <translation>Regler:</translation>
    </message>
    <message>
        <source>Weapons:</source>
        <translation>Vapen:</translation>
    </message>
    <message>
        <source>Search:</source>
        <translation>Sök:</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Rensa</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Varning</translation>
    </message>
    <message>
        <source>The game you are trying to join has started.
Do you still want to join the room?</source>
        <translation>Spelet du försöker gå med i har startat.
Vill du fortfarande gå med i rummet?</translation>
    </message>
    <message numerus="yes">
        <source>%1 players online</source>
        <translation>
            <numerusform>%1 spelare inne</numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>PageScheme</name>
    <message>
        <source>New</source>
        <translation>Ny</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Ta bort</translation>
    </message>
    <message>
        <source>Enable random mines</source>
        <translation type="obsolete">Aktivera slumpade minor</translation>
    </message>
    <message>
        <source>Gain 80% of the damage you do back in health</source>
        <translation>Få 80% av skadan du gör tillbaka i liv</translation>
    </message>
    <message>
        <source>Share your opponents pain, share their damage</source>
        <translation>Dela dina fienders smärta, dela deras skada</translation>
    </message>
    <message>
        <source>Your hogs are unable to move, put your artillery skills to the test</source>
        <translation>Dina igelkottar kan inte röra sig, din artilleriskicklighet ställs på prov</translation>
    </message>
    <message>
        <source>Random</source>
        <translation>Slumpad</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Sekunder</translation>
    </message>
    <message>
        <source>Defend your fort and destroy the opponents, two team colours max!</source>
        <translation>Skydda ditt fort och förstör motståndarens, två lagfärger max!</translation>
    </message>
    <message>
        <source>Teams will start on opposite sides of the terrain, two team colours max!</source>
        <translation>Lag startar på motsatta sidor av terrängen, två lagfärger max!</translation>
    </message>
    <message>
        <source>Land can not be destroyed!</source>
        <translation>Land kan inte förstöras!</translation>
    </message>
    <message>
        <source>Add an indestructable border around the terrain</source>
        <translation type="obsolete">Lägger till en oförstörbar kant runt terrängen</translation>
    </message>
    <message>
        <source>Lower gravity</source>
        <translation>Lägre gravitation</translation>
    </message>
    <message>
        <source>Assisted aiming with laser sight</source>
        <translation>Få hjälp med siktande med lasersikte</translation>
    </message>
    <message>
        <source>All hogs have a personal forcefield</source>
        <translation>Alla igelkottar har ett personligt skyddsfält</translation>
    </message>
    <message>
        <source>Order of play is random instead of in room order.</source>
        <translation>Spelording är slumpvald istället för i rumsordning.</translation>
    </message>
    <message>
        <source>Play with a King. If he dies, your side dies.</source>
        <translation>Spela med en kung. Om han dör, dör din sida.</translation>
    </message>
    <message>
        <source>Take turns placing your hedgehogs before the start of play.</source>
        <translation>Turas om att placera ut era igelkottar innan spelet börjar.</translation>
    </message>
    <message>
        <source>Ammo is shared between all teams that share a colour.</source>
        <translation>Ammunition delas mellan alla lag med samma färg.</translation>
    </message>
    <message>
        <source>Disable girders when generating random maps.</source>
        <translation>Avaktivera balkar när slumpade kartor genereras.</translation>
    </message>
    <message>
        <source>Disable land objects when generating random maps.</source>
        <translation>Avaktivera landföremål när slumpade kartor genereras.</translation>
    </message>
    <message>
        <source>AI respawns on death.</source>
        <translation>AI kommer tillbaka när de dör.</translation>
    </message>
    <message>
        <source>All (living) hedgehogs are fully restored at the end of turn</source>
        <translation>Alla (levande) igelkottar återfår sin hälsa i slutet av varje tur</translation>
    </message>
    <message>
        <source>Attacking does not end your turn.</source>
        <translation>Att använda vapen avslutar inte din tur.</translation>
    </message>
    <message>
        <source>Weapons are reset to starting values each turn.</source>
        <translation>Vapnen nollställs till startvärderna varje tur.</translation>
    </message>
    <message>
        <source>Each hedgehog has its own ammo. It does not share with the team.</source>
        <translation>Varje igelkott har sin egen ammunition. Laget delar inte med varandra.</translation>
    </message>
    <message>
        <source>You will not have to worry about wind anymore.</source>
        <translation>Nu behöver du inte oroa dig för vinden längre.</translation>
    </message>
    <message>
        <source>Wind will affect almost everything.</source>
        <translation>Vind påverkar nästan allting.</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiera</translation>
    </message>
    <message>
        <source>Teams in each clan take successive turns sharing their turn time.</source>
        <translation>Lag inom en klan spelar efter varandra och delar på turtiden.</translation>
    </message>
    <message>
        <source>Add an indestructible border around the terrain</source>
        <translation>Lägger till en oförstörbar kant runt terrängen</translation>
    </message>
    <message>
        <source>Add an indestructible border along the bottom</source>
        <translation>Lägg till en oförstörbar barriär längs botten</translation>
    </message>
</context>
<context>
    <name>PageSelectWeapon</name>
    <message>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Ta bort</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Ny</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiera</translation>
    </message>
</context>
<context>
    <name>PageSinglePlayer</name>
    <message>
        <source>Simple Game (a quick game against the computer, settings are chosen for you)</source>
        <translation>Enkelt spel (en snabbomgång mot datorn, inställningar väljs åt dig)</translation>
    </message>
    <message>
        <source>Multiplayer (play a hotseat game against your friends, or AI teams)</source>
        <translation>Flera spelare (spela en hotseat-omgång mot dina vänner eller AI-lag)</translation>
    </message>
    <message>
        <source>Training Mode (Practice your skills in a range of training missions). IN DEVELOPMENT</source>
        <translation>Träningsläge (öva dina färdigheter i en rad träningsuppdrag). UNDER UTVECKLING</translation>
    </message>
    <message>
        <source>Demos (Watch recorded demos)</source>
        <translation>Demos (se inspelade demos)</translation>
    </message>
    <message>
        <source>Load (Load a previously saved game)</source>
        <translation>Ladda (ladda ett tidigare sparat spel)</translation>
    </message>
    <message>
        <source>Campaign Mode (...). IN DEVELOPMENT</source>
        <translation>Kampanjläge (...). UNDER UTVECKLING</translation>
    </message>
</context>
<context>
    <name>QAction</name>
    <message>
        <source>Kick</source>
        <translation>Släng ut</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Starta</translation>
    </message>
    <message>
        <source>Restrict Joins</source>
        <translation>Begränsa tillkommande</translation>
    </message>
    <message>
        <source>Restrict Team Additions</source>
        <translation>Begränsa tillägg av lag</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Information</translation>
    </message>
    <message>
        <source>Ban</source>
        <translation>Banna</translation>
    </message>
    <message>
        <source>Follow</source>
        <translation>Följ</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorera</translation>
    </message>
    <message>
        <source>Add friend</source>
        <translation>Lägg till som vän</translation>
    </message>
    <message>
        <source>Unignore</source>
        <translation>Avignorera</translation>
    </message>
    <message>
        <source>Remove friend</source>
        <translation>Ta bort som vän</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Uppdatera</translation>
    </message>
</context>
<context>
    <name>QCheckBox</name>
    <message>
        <source>Fullscreen</source>
        <translation>Helskärm</translation>
    </message>
    <message>
        <source>Enable sound</source>
        <translation>Aktivera ljud</translation>
    </message>
    <message>
        <source>Show FPS</source>
        <translation>Visa FPS (rutor per sekund)</translation>
    </message>
    <message>
        <source>Alternative damage show</source>
        <translation>Visa alternativ skada</translation>
    </message>
    <message>
        <source>Enable music</source>
        <translation>Aktivera musik</translation>
    </message>
    <message>
        <source>Frontend fullscreen</source>
        <translation>Spelmenyn i helskärm</translation>
    </message>
    <message>
        <source>Append date and time to record file name</source>
        <translation>Bifoga datum och tid till namnet på inspelningsfiler</translation>
    </message>
    <message>
        <source>Check for updates at startup</source>
        <translation>Leta efter uppdatering vid programstart</translation>
    </message>
    <message>
        <source>Reduced quality</source>
        <translation type="obsolete">Minskad kvalité</translation>
    </message>
    <message>
        <source>Show ammo menu tooltips</source>
        <translation>Visa hjälp i ammunitionsmenyn</translation>
    </message>
    <message>
        <source>Enable frontend sounds</source>
        <translation>Aktivera ljud i spelmenyn</translation>
    </message>
    <message>
        <source>Enable frontend music</source>
        <translation>Aktivera musik i spelmenyn</translation>
    </message>
    <message>
        <source>Frontend effects</source>
        <translation>Effekter i spelmenyn</translation>
    </message>
</context>
<context>
    <name>QComboBox</name>
    <message>
        <source>generated map...</source>
        <translation>genererad karta...</translation>
    </message>
    <message>
        <source>Human</source>
        <translation>Människa</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>Nivå</translation>
    </message>
    <message>
        <source>(System default)</source>
        <translation>(Systemstandard)</translation>
    </message>
    <message>
        <source>generated maze...</source>
        <translation>genererad labyrint...</translation>
    </message>
    <message>
        <source>Mission</source>
        <translation>Uppdrag</translation>
    </message>
    <message>
        <source>Community</source>
        <translation>Gemenskap</translation>
    </message>
    <message>
        <source>Any</source>
        <translation>Vilken som</translation>
    </message>
    <message>
        <source>In lobby</source>
        <translation>I lobby</translation>
    </message>
    <message>
        <source>In progress</source>
        <translation>Pågår</translation>
    </message>
    <message>
        <source>Default</source>
        <translation type="obsolete">Standard</translation>
    </message>
    <message>
        <source>Pro mode</source>
        <translation type="obsolete">Pro-läge</translation>
    </message>
    <message>
        <source>Shoppa</source>
        <translation type="obsolete">Shoppa</translation>
    </message>
    <message>
        <source>Basketball</source>
        <translation type="obsolete">Basket</translation>
    </message>
    <message>
        <source>Minefield</source>
        <translation type="obsolete">Minfält</translation>
    </message>
    <message>
        <source>Barrel mayhem</source>
        <translation type="obsolete">Tunnförödelse</translation>
    </message>
    <message>
        <source>Tunnel hogs</source>
        <translation type="obsolete">Tunnelkottar</translation>
    </message>
    <message>
        <source>Crazy</source>
        <translation type="obsolete">Galet</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation type="obsolete">Vanligt</translation>
    </message>
    <message>
        <source>hand drawn map...</source>
        <translation>handritad karta...</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Avaktiverad</translation>
    </message>
    <message>
        <source>Red/Cyan</source>
        <translation>Röd/Cyan</translation>
    </message>
    <message>
        <source>Cyan/Red</source>
        <translation>Cyan/Röd</translation>
    </message>
    <message>
        <source>Red/Blue</source>
        <translation>Röd/Blå</translation>
    </message>
    <message>
        <source>Blue/Red</source>
        <translation>Blå/Röd</translation>
    </message>
    <message>
        <source>Red/Green</source>
        <translation>Röd/Grön</translation>
    </message>
    <message>
        <source>Green/Red</source>
        <translation>Grön/Röd</translation>
    </message>
    <message>
        <source>Side-by-side</source>
        <translation>Sida vid sida</translation>
    </message>
    <message>
        <source>Top-Bottom</source>
        <translation>Uppe och nere</translation>
    </message>
    <message>
        <source>Wiggle</source>
        <translation>Vicka</translation>
    </message>
    <message>
        <source>Red/Cyan grayscale</source>
        <translation>Röd/Cyan gråskala</translation>
    </message>
    <message>
        <source>Cyan/Red grayscale</source>
        <translation>Cyan/Röd gråskala</translation>
    </message>
    <message>
        <source>Red/Blue grayscale</source>
        <translation>Röd/Blå gråskala</translation>
    </message>
    <message>
        <source>Blue/Red grayscale</source>
        <translation>Blå/Röd gråskala</translation>
    </message>
    <message>
        <source>Red/Green grayscale</source>
        <translation>Röd/Grön gråskala</translation>
    </message>
    <message>
        <source>Green/Red grayscale</source>
        <translation>Grön/Röd gråskala</translation>
    </message>
</context>
<context>
    <name>QGroupBox</name>
    <message>
        <source>Team Members</source>
        <translation>Lagmedlemmar</translation>
    </message>
    <message>
        <source>Key binds</source>
        <translation>Tangentbindningar</translation>
    </message>
    <message>
        <source>Fort</source>
        <translation>Fort</translation>
    </message>
    <message>
        <source>Teams</source>
        <translation>Lag</translation>
    </message>
    <message>
        <source>Audio/Graphic options</source>
        <translation>Ljud/grafikinställningar</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation type="obsolete">Vapen</translation>
    </message>
    <message>
        <source>Net game</source>
        <translation>Internetspel</translation>
    </message>
    <message>
        <source>Playing teams</source>
        <translation>Spelande lag</translation>
    </message>
    <message>
        <source>Game Modifiers</source>
        <translation>Spellägen</translation>
    </message>
    <message>
        <source>Basic Settings</source>
        <translation>Allmäna inställningar</translation>
    </message>
    <message>
        <source>Team Settings</source>
        <translation>Laginställningar</translation>
    </message>
    <message>
        <source>Misc</source>
        <translation>Diverse</translation>
    </message>
    <message>
        <source>Schemes and Weapons</source>
        <translation>Scheman och vapen</translation>
    </message>
</context>
<context>
    <name>QLabel</name>
    <message>
        <source>This program is distributed under the GNU General Public License</source>
        <translation>Detta program distribueras under GNU General Public License</translation>
    </message>
    <message>
        <source>Developers:</source>
        <translation>Utvecklare:</translation>
    </message>
    <message>
        <source>Art:</source>
        <translation>Grafik:</translation>
    </message>
    <message>
        <source>Translations:</source>
        <translation>Översättningar:</translation>
    </message>
    <message>
        <source>Special thanks:</source>
        <translation>Särskilt tack till:</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation>Vapen</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Värd:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Upplösning</translation>
    </message>
    <message>
        <source>FPS limit</source>
        <translation>FPS-begränsning</translation>
    </message>
    <message>
        <source>Net nick</source>
        <translation>Internetnamn</translation>
    </message>
    <message>
        <source>Server name:</source>
        <translation>Servernamn:</translation>
    </message>
    <message>
        <source>Server port:</source>
        <translation>Serverport:</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Version</translation>
    </message>
    <message>
        <source>Sounds:</source>
        <translation>Ljud:</translation>
    </message>
    <message>
        <source>Initial sound volume</source>
        <translation>Ursprunglig ljudvolym</translation>
    </message>
    <message>
        <source>Damage Modifier</source>
        <translation>Skadeprocent</translation>
    </message>
    <message>
        <source>Turn Time</source>
        <translation>Tid per tur</translation>
    </message>
    <message>
        <source>Initial Health</source>
        <translation>Ursprungligt liv</translation>
    </message>
    <message>
        <source>Sudden Death Timeout</source>
        <translation>Rundor till Sudden Death</translation>
    </message>
    <message>
        <source>Mines Time</source>
        <translation>Mintid</translation>
    </message>
    <message>
        <source>Mines</source>
        <translation>Minor</translation>
    </message>
    <message>
        <source>Scheme Name:</source>
        <translation>Schemanamn:</translation>
    </message>
    <message>
        <source>Crate Drops</source>
        <translation>Lådor</translation>
    </message>
    <message>
        <source>Game scheme</source>
        <translation>Spelschema</translation>
    </message>
    <message>
        <source>% Dud Mines</source>
        <translation>% falska minor</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Namn</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <source>Grave</source>
        <translation>Grav</translation>
    </message>
    <message>
        <source>Flag</source>
        <translation>Flagga</translation>
    </message>
    <message>
        <source>Voice</source>
        <translation>Röst</translation>
    </message>
    <message>
        <source>Locale</source>
        <translation>Språk</translation>
    </message>
    <message>
        <source>Restart game to apply</source>
        <translation>Starta om spelet för att verkställa</translation>
    </message>
    <message>
        <source>This SVN build is &apos;work in progress&apos; and may not be compatible with other versions of the game.
Some features might be broken or incomplete. Use at your own risk!</source>
        <translation type="obsolete">Detta SVN-bygge är &apos;under utveckling&apos; och kanske inte är kompatibel med andra versioner av spelet.
Det kan finnas trasiga eller ofullständiga funktioner. Använd på egen risk!</translation>
    </message>
    <message>
        <source>Explosives</source>
        <translation>Bombtunnor</translation>
    </message>
    <message>
        <source>Tip: </source>
        <translation>Tips:</translation>
    </message>
    <message>
        <source>This development build is &apos;work in progress&apos; and may not be compatible with other versions of the game. Some features might be broken or incomplete. Use at your own risk!</source>
        <translation>Denna utvecklingsversion är inte färdig och kanske inte är kompatibel med andra versioner av spelet. Några delar kan vara trasiga eller ofullständiga. Använd på egen risk!</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Kvalitet</translation>
    </message>
    <message>
        <source>% Health Crates</source>
        <translation>% förbandslådor</translation>
    </message>
    <message>
        <source>Health in Crates</source>
        <translation>Liv i förbandslådor</translation>
    </message>
    <message>
        <source>Sudden Death Water Rise</source>
        <translation>Sudden Death vattenhöjning</translation>
    </message>
    <message>
        <source>Sudden Death Health Decrease</source>
        <translation>Sudden Death livminskning</translation>
    </message>
    <message>
        <source>% Rope Length</source>
        <translation>% replängd</translation>
    </message>
    <message>
        <source>Gameplay</source>
        <translation type="obsolete">Speltyp</translation>
    </message>
    <message>
        <source>Stereo rendering</source>
        <translation>Stereorendering</translation>
    </message>
    <message>
        <source>Game Options</source>
        <translation>Spelinställningar</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Stil</translation>
    </message>
    <message>
        <source>Scheme</source>
        <translation>Schema</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Lösenord</translation>
    </message>
    <message>
        <source>% Get Away Time</source>
        <translation>% flykttid</translation>
    </message>
</context>
<context>
    <name>QLineEdit</name>
    <message>
        <source>unnamed</source>
        <translation>onämnd</translation>
    </message>
    <message>
        <source>hedgehog %1</source>
        <translation>igelkott %1</translation>
    </message>
</context>
<context>
    <name>QMainWindow</name>
    <message>
        <source>Hedgewars %1</source>
        <translation>Hedgewars %1</translation>
    </message>
</context>
<context>
    <name>QMessageBox</name>
    <message>
        <source>Network</source>
        <translation>Nätverk</translation>
    </message>
    <message>
        <source>Connection to server is lost</source>
        <translation>Ansluting till servern bröts</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fel</translation>
    </message>
    <message>
        <source>Failed to open data directory:
%1
Please check your installation</source>
        <translation>Kunde inte öppna datakatalog:
%1
Var god kontrollera din installation</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation>Vapen</translation>
    </message>
    <message>
        <source>Can not edit default weapon set</source>
        <translation type="obsolete">Kan inte redigera ursprungliga vapenscheman</translation>
    </message>
    <message>
        <source>Can not delete default weapon set</source>
        <translation type="obsolete">Kan inte ta bort ursprungliga vapenscheman</translation>
    </message>
    <message>
        <source>Really delete this weapon set?</source>
        <translation>Vill du verkligen ta bort detta vapenschema?</translation>
    </message>
    <message>
        <source>Can not overwrite default weapon set &apos;%1&apos;!</source>
        <translation>Kan inte skriva över standardvapenschema &apos;%1&apos;!</translation>
    </message>
    <message>
        <source>All file associations have been set.</source>
        <translation>Alla filassociationer har satts.</translation>
    </message>
    <message>
        <source>File association failed.</source>
        <translation>Filassociationer har misslyckats.</translation>
    </message>
    <message>
        <source>Teams</source>
        <translation>Lag</translation>
    </message>
    <message>
        <source>Really delete this team?</source>
        <translation>Vill du verkligen ta bort detta lag?</translation>
    </message>
    <message>
        <source>Schemes</source>
        <translation>Scheman</translation>
    </message>
    <message>
        <source>Can not delete default scheme &apos;%1&apos;!</source>
        <translation>Kan inte ta bort standardschema &apos;%1&apos;!</translation>
    </message>
    <message>
        <source>Really delete this game scheme?</source>
        <translation>Vill du verkligen ta bort detta spelschema?</translation>
    </message>
    <message>
        <source>Can not delete default weapon set &apos;%1&apos;!</source>
        <translation>Kan inte ta bort standardvapenset &apos;%1&apos;!</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Error</source>
        <translation>Fel</translation>
    </message>
    <message>
        <source>Cannot create directory %1</source>
        <translation>Kan inte skapa katalog %1</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Smeknamn</translation>
    </message>
    <message>
        <source>Please enter your nickname</source>
        <translation>Var god ange ditt smeknamn</translation>
    </message>
</context>
<context>
    <name>QPushButton</name>
    <message>
        <source>Go!</source>
        <translation>Kör!</translation>
    </message>
    <message>
        <source>default</source>
        <translation>standard</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <source>Start server</source>
        <translation>Starta server</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Anslut</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Uppdatera</translation>
    </message>
    <message>
        <source>Specify</source>
        <translation>Ange</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Starta</translation>
    </message>
    <message>
        <source>Play demo</source>
        <translation>Spela upp demo</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Byt namn</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Ta bort</translation>
    </message>
    <message>
        <source>Load</source>
        <translation>Läs in</translation>
    </message>
    <message>
        <source>Setup</source>
        <translation>Inställningar</translation>
    </message>
    <message>
        <source>Ready</source>
        <translation>Redo</translation>
    </message>
    <message>
        <source>Random Team</source>
        <translation>Slumpat lag</translation>
    </message>
    <message>
        <source>Associate file extensions</source>
        <translation>Associera filextentioner</translation>
    </message>
    <message>
        <source>Set</source>
        <translation type="obsolete">Ange</translation>
    </message>
    <message>
        <source>more</source>
        <translation>mer</translation>
    </message>
</context>
<context>
    <name>QTableWidget</name>
    <message>
        <source>Room Name</source>
        <translation>Rumnamn</translation>
    </message>
    <message>
        <source>C</source>
        <translation>A</translation>
    </message>
    <message>
        <source>T</source>
        <translation>L</translation>
    </message>
    <message>
        <source>Owner</source>
        <translation>Ägare</translation>
    </message>
    <message>
        <source>Map</source>
        <translation>Karta</translation>
    </message>
    <message>
        <source>Rules</source>
        <translation>Regler</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation>Vapen</translation>
    </message>
</context>
<context>
    <name>SelWeaponWidget</name>
    <message>
        <source>Weapon set</source>
        <translation>Vapenset</translation>
    </message>
    <message>
        <source>Probabilities</source>
        <translation>Sannorlikheter</translation>
    </message>
    <message>
        <source>Ammo in boxes</source>
        <translation>Ammunition i lådor</translation>
    </message>
    <message>
        <source>Delays</source>
        <translation>Fördröjning</translation>
    </message>
    <message>
        <source>new</source>
        <translation>ny</translation>
    </message>
    <message>
        <source>copy of</source>
        <translation>kopia av</translation>
    </message>
</context>
<context>
    <name>TCPBase</name>
    <message>
        <source>Error</source>
        <translation>Fel</translation>
    </message>
    <message>
        <source>Unable to start the server: %1.</source>
        <translation>Kunde inte starta servern: %1.</translation>
    </message>
    <message>
        <source>Unable to run engine: %1 (</source>
        <translation>Kunde inte köra motorn: %1 (</translation>
    </message>
</context>
<context>
    <name>ToggleButtonWidget</name>
    <message>
        <source>Vampirism</source>
        <translation>Vampyrism</translation>
    </message>
    <message>
        <source>Karma</source>
        <translation>Karma</translation>
    </message>
    <message>
        <source>Artillery</source>
        <translation>Artilleri</translation>
    </message>
    <message>
        <source>Fort Mode</source>
        <translation>Fortläge</translation>
    </message>
    <message>
        <source>Divide Teams</source>
        <translation>Dela upp lag</translation>
    </message>
    <message>
        <source>Solid Land</source>
        <translation>Solitt land</translation>
    </message>
    <message>
        <source>Add Border</source>
        <translation>Lägg till kant</translation>
    </message>
    <message>
        <source>Low Gravity</source>
        <translation>Låg gravitation</translation>
    </message>
    <message>
        <source>Laser Sight</source>
        <translation>Lasersikte</translation>
    </message>
    <message>
        <source>Invulnerable</source>
        <translation>Osårbar</translation>
    </message>
    <message>
        <source>Add Mines</source>
        <translation type="obsolete">Lägg till minor</translation>
    </message>
    <message>
        <source>Random Order</source>
        <translation>Slumpad ordning</translation>
    </message>
    <message>
        <source>King</source>
        <translation>Kung</translation>
    </message>
    <message>
        <source>Place Hedgehogs</source>
        <translation>Placera igelkottar</translation>
    </message>
    <message>
        <source>Clan Shares Ammo</source>
        <translation>Klan delar ammunition</translation>
    </message>
    <message>
        <source>Disable Girders</source>
        <translation>Avaktivera balkar</translation>
    </message>
    <message>
        <source>Disable Land Objects</source>
        <translation>Avaktivera landföremål</translation>
    </message>
    <message>
        <source>AI Survival Mode</source>
        <translation>AI-överlevnad</translation>
    </message>
    <message>
        <source>Reset Health</source>
        <translation>Återställ hälsa</translation>
    </message>
    <message>
        <source>Unlimited Attacks</source>
        <translation>Obegränsade attacker</translation>
    </message>
    <message>
        <source>Reset Weapons</source>
        <translation>Återställ vapen</translation>
    </message>
    <message>
        <source>Per Hedgehog Ammo</source>
        <translation>Ammunition per igelkott</translation>
    </message>
    <message>
        <source>Disable Wind</source>
        <translation>Avaktivera vind</translation>
    </message>
    <message>
        <source>More Wind</source>
        <translation>Mer vind</translation>
    </message>
    <message>
        <source>Tag Team</source>
        <translation>Maraton</translation>
    </message>
    <message>
        <source>Add Bottom Border</source>
        <translation>Lägg till undre barriär</translation>
    </message>
</context>
<context>
    <name>binds</name>
    <message>
        <source>up</source>
        <translation>upp</translation>
    </message>
    <message>
        <source>left</source>
        <translation>vänster</translation>
    </message>
    <message>
        <source>right</source>
        <translation>höger</translation>
    </message>
    <message>
        <source>down</source>
        <translation>ned</translation>
    </message>
    <message>
        <source>attack</source>
        <translation>attackera</translation>
    </message>
    <message>
        <source>put</source>
        <translation>placera</translation>
    </message>
    <message>
        <source>switch</source>
        <translation>byt</translation>
    </message>
    <message>
        <source>find hedgehog</source>
        <translation>hitta igelkott</translation>
    </message>
    <message>
        <source>ammo menu</source>
        <translation>ammunitionsmeny</translation>
    </message>
    <message>
        <source>slot 1</source>
        <translation>fack 1</translation>
    </message>
    <message>
        <source>slot 2</source>
        <translation>fack 2</translation>
    </message>
    <message>
        <source>slot 3</source>
        <translation>fack 3</translation>
    </message>
    <message>
        <source>slot 4</source>
        <translation>fack 4</translation>
    </message>
    <message>
        <source>slot 5</source>
        <translation>fack 5</translation>
    </message>
    <message>
        <source>slot 6</source>
        <translation>fack 6</translation>
    </message>
    <message>
        <source>slot 7</source>
        <translation>fack 7</translation>
    </message>
    <message>
        <source>slot 8</source>
        <translation>fack 8</translation>
    </message>
    <message>
        <source>slot 9</source>
        <translation>fack 9</translation>
    </message>
    <message>
        <source>timer 1 sec</source>
        <translation>tid 1 sek</translation>
    </message>
    <message>
        <source>timer 2 sec</source>
        <translation>tid 2 sek</translation>
    </message>
    <message>
        <source>timer 3 sec</source>
        <translation>tid 3 sek</translation>
    </message>
    <message>
        <source>timer 4 sec</source>
        <translation>tid 4 sek</translation>
    </message>
    <message>
        <source>timer 5 sec</source>
        <translation>tid 5 sek</translation>
    </message>
    <message>
        <source>pause</source>
        <translation>pausa</translation>
    </message>
    <message>
        <source>volume down</source>
        <translation>sänk volym</translation>
    </message>
    <message>
        <source>volume up</source>
        <translation>höj volym</translation>
    </message>
    <message>
        <source>change mode</source>
        <translation>byt skärmläge</translation>
    </message>
    <message>
        <source>capture</source>
        <translation>ta bild</translation>
    </message>
    <message>
        <source>hedgehogs
info</source>
        <translation>information om igelkottar</translation>
    </message>
    <message>
        <source>quit</source>
        <translation>avsluta</translation>
    </message>
    <message>
        <source>chat</source>
        <translation>chatt</translation>
    </message>
    <message>
        <source>chat history</source>
        <translation>chatthistorik</translation>
    </message>
    <message>
        <source>confirmation</source>
        <translation>bekräftelse</translation>
    </message>
    <message>
        <source>precise aim</source>
        <translation>exakt sikte</translation>
    </message>
    <message>
        <source>zoom in</source>
        <translation>zooma in</translation>
    </message>
    <message>
        <source>zoom out</source>
        <translation>zooma ut</translation>
    </message>
    <message>
        <source>reset zoom</source>
        <translation>återställ zoom</translation>
    </message>
    <message>
        <source>long jump</source>
        <translation>långhopp</translation>
    </message>
    <message>
        <source>high jump</source>
        <translation>högt hopp</translation>
    </message>
    <message>
        <source>slot 10</source>
        <translation>fack 10</translation>
    </message>
</context>
<context>
    <name>binds (categories)</name>
    <message>
        <source>Basic controls</source>
        <translation>Allmäna kontroller</translation>
    </message>
    <message>
        <source>Weapon controls</source>
        <translation>Vanenkontroller</translation>
    </message>
    <message>
        <source>Camera and cursor controls</source>
        <translation>Kamera och pilkontroller</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Annat</translation>
    </message>
</context>
<context>
    <name>binds (descriptions)</name>
    <message>
        <source>Move your hogs and aim:</source>
        <translation>Flytta dina igelkottar och sikta:</translation>
    </message>
    <message>
        <source>Traverse gaps and obstacles by jumping:</source>
        <translation>Undvik hål och hinder genom att hoppa:</translation>
    </message>
    <message>
        <source>Fire your selected weapon or trigger an utility item:</source>
        <translation>Använd ditt valda vapen eller använd ett verktyg:</translation>
    </message>
    <message>
        <source>Pick a weapon or a target location under the cursor:</source>
        <translation>Välj ett vapen eller ett mål under markören:</translation>
    </message>
    <message>
        <source>Switch your currently active hog (if possible):</source>
        <translation>Byt din nuvarande aktiva igelkott (om möjligt):</translation>
    </message>
    <message>
        <source>Pick a weapon or utility item:</source>
        <translation>Välj ett vapen eller verktyg:</translation>
    </message>
    <message>
        <source>Set the timer on bombs and timed weapons:</source>
        <translation>Ställ in bombtimer och tidsinställda vapen:</translation>
    </message>
    <message>
        <source>Move the camera to the active hog:</source>
        <translation>Flytta kameran till aktiv igelkotte:</translation>
    </message>
    <message>
        <source>Move the cursor or camera without using the mouse:</source>
        <translation>Flytta pilen eller kameran utan att använda musen:</translation>
    </message>
    <message>
        <source>Modify the camera&apos;s zoom level:</source>
        <translation>Ändra kamerans zoomnivå:</translation>
    </message>
    <message>
        <source>Talk to your team or all participants:</source>
        <translation>Prata med ditt lag eller alla deltagare:</translation>
    </message>
    <message>
        <source>Pause, continue or leave your game:</source>
        <translation>Pausa, fortsätt eller avsluta ditt spel:</translation>
    </message>
    <message>
        <source>Modify the game&apos;s volume while playing:</source>
        <translation>Ändra spelvolym medans du spelar:</translation>
    </message>
    <message>
        <source>Toggle fullscreen mode:</source>
        <translation>Byt till/från helskärmsläge:</translation>
    </message>
    <message>
        <source>Take a screenshot:</source>
        <translation>Ta en skärmbild:</translation>
    </message>
    <message>
        <source>Toggle labels above hedgehogs:</source>
        <translation>Visa etiketter över igelkottar:</translation>
    </message>
</context>
<context>
    <name>binds (keys)</name>
    <message>
        <source>Axis</source>
        <translation>Axlar</translation>
    </message>
    <message>
        <source>(Up)</source>
        <translation>(Upp)</translation>
    </message>
    <message>
        <source>(Down)</source>
        <translation>(Ner)</translation>
    </message>
    <message>
        <source>Hat</source>
        <translation>Hatt</translation>
    </message>
    <message>
        <source>(Left)</source>
        <translation>(Vänster)</translation>
    </message>
    <message>
        <source>(Right)</source>
        <translation>(Höger)</translation>
    </message>
    <message>
        <source>Button</source>
        <translation>Knapp</translation>
    </message>
    <message>
        <source>Keyboard</source>
        <translation>Tangentbord</translation>
    </message>
    <message>
        <source>Mouse: Left button</source>
        <translation>Mus: Vänsterknapp</translation>
    </message>
    <message>
        <source>Mouse: Middle button</source>
        <translation>Mus: Mittenknapp</translation>
    </message>
    <message>
        <source>Mouse: Right button</source>
        <translation>Mus: Högerknapp</translation>
    </message>
    <message>
        <source>Mouse: Wheel up</source>
        <translation>Mus: Hjul upp</translation>
    </message>
    <message>
        <source>Mouse: Wheel down</source>
        <translation>Mus: Hjul ner</translation>
    </message>
    <message>
        <source>Backspace</source>
        <translation>Baksteg</translation>
    </message>
    <message>
        <source>Tab</source>
        <translation>Tabb</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Clear</translation>
    </message>
    <message>
        <source>Return</source>
        <translation>Return</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Escape</source>
        <translation>Escape</translation>
    </message>
    <message>
        <source>Space</source>
        <translation>Mellanslag</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Delete</translation>
    </message>
    <message>
        <source>Numpad 0</source>
        <translation>Numpad 0</translation>
    </message>
    <message>
        <source>Numpad 1</source>
        <translation>Numpad 1</translation>
    </message>
    <message>
        <source>Numpad 2</source>
        <translation>Numpad 2</translation>
    </message>
    <message>
        <source>Numpad 3</source>
        <translation>Numpad 3</translation>
    </message>
    <message>
        <source>Numpad 4</source>
        <translation>Numpad 4</translation>
    </message>
    <message>
        <source>Numpad 5</source>
        <translation>Numpad 5</translation>
    </message>
    <message>
        <source>Numpad 6</source>
        <translation>Numpad 6</translation>
    </message>
    <message>
        <source>Numpad 7</source>
        <translation>Numpad 7</translation>
    </message>
    <message>
        <source>Numpad 8</source>
        <translation>Numpad 8</translation>
    </message>
    <message>
        <source>Numpad 9</source>
        <translation>Numpad 9</translation>
    </message>
    <message>
        <source>Numpad .</source>
        <translation>Numpad .</translation>
    </message>
    <message>
        <source>Numpad /</source>
        <translation>Numpad /</translation>
    </message>
    <message>
        <source>Numpad *</source>
        <translation>Numpad *</translation>
    </message>
    <message>
        <source>Numpad -</source>
        <translation>Numpad -</translation>
    </message>
    <message>
        <source>Numpad +</source>
        <translation>Numpad +</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>Retur</translation>
    </message>
    <message>
        <source>Equals</source>
        <translation>Lika med</translation>
    </message>
    <message>
        <source>Up</source>
        <translation>Upp</translation>
    </message>
    <message>
        <source>Down</source>
        <translation>Ned</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Höger</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Vänster</translation>
    </message>
    <message>
        <source>Insert</source>
        <translation>Insert</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Home</translation>
    </message>
    <message>
        <source>End</source>
        <translation>End</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Page up</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Page down</translation>
    </message>
    <message>
        <source>Num lock</source>
        <translation>Num lock</translation>
    </message>
    <message>
        <source>Caps lock</source>
        <translation>Caps lock</translation>
    </message>
    <message>
        <source>Scroll lock</source>
        <translation>Scroll lock</translation>
    </message>
    <message>
        <source>Right shift</source>
        <translation>Höger shift</translation>
    </message>
    <message>
        <source>Left shift</source>
        <translation>Vänster shift</translation>
    </message>
    <message>
        <source>Right ctrl</source>
        <translation>Höger ctrl</translation>
    </message>
    <message>
        <source>Left ctrl</source>
        <translation>Vänster ctrl</translation>
    </message>
    <message>
        <source>Right alt</source>
        <translation>Höger alt</translation>
    </message>
    <message>
        <source>Left alt</source>
        <translation>Vänster alt</translation>
    </message>
    <message>
        <source>Right meta</source>
        <translation>Höger meta</translation>
    </message>
    <message>
        <source>Left meta</source>
        <translation>Vänster meta</translation>
    </message>
    <message>
        <source>A button</source>
        <translation>A-knappen</translation>
    </message>
    <message>
        <source>B button</source>
        <translation>B-knappen</translation>
    </message>
    <message>
        <source>X button</source>
        <translation>X-knappen</translation>
    </message>
    <message>
        <source>Y button</source>
        <translation>Y-knappen</translation>
    </message>
    <message>
        <source>LB button</source>
        <translation>LB-knappen</translation>
    </message>
    <message>
        <source>RB button</source>
        <translation>RB-knappen</translation>
    </message>
    <message>
        <source>Back button</source>
        <translation>Back-knappen</translation>
    </message>
    <message>
        <source>Start button</source>
        <translation>Start-knappen</translation>
    </message>
    <message>
        <source>Left stick</source>
        <translation>Vänster styrpinne</translation>
    </message>
    <message>
        <source>Right stick</source>
        <translation>Höger styrpinne</translation>
    </message>
    <message>
        <source>Left stick (Right)</source>
        <translation>Vänster styrpinne (Höger)</translation>
    </message>
    <message>
        <source>Left stick (Left)</source>
        <translation>Vänster styrpinne (Vänster)</translation>
    </message>
    <message>
        <source>Left stick (Down)</source>
        <translation>Vänster styrpinne (Ned)</translation>
    </message>
    <message>
        <source>Left stick (Up)</source>
        <translation>Vänster styrpinne (Upp)</translation>
    </message>
    <message>
        <source>Left trigger</source>
        <translation>Vänster avtryckare</translation>
    </message>
    <message>
        <source>Right trigger</source>
        <translation>Höger avtryckare</translation>
    </message>
    <message>
        <source>Right stick (Down)</source>
        <translation>Höger styrpinne (Ned)</translation>
    </message>
    <message>
        <source>Right stick (Up)</source>
        <translation>Höger styrpinne (Upp)</translation>
    </message>
    <message>
        <source>Right stick (Right)</source>
        <translation>Höger styrpinne (Höger)</translation>
    </message>
    <message>
        <source>Right stick (Left)</source>
        <translation>Höger styrpinne (Vänster)</translation>
    </message>
    <message>
        <source>DPad</source>
        <translation>Styrkors</translation>
    </message>
</context>
</TS>
